@@ -13,14 +13,6 @@
 ##################################################
 ##################################################
 
-# Change History:
-#   Version 1.0 - Initial implementation
-#   96 Jan 15	ringger@cs.rochester.edu - Fixed dialogue box creation.
-#   96 Jan 15	ringger - Added option for selecting directories.
-#   96 Feb 29	powers - Rewrote and componentized, and added a bunch of
-#		options.  Now requires perl 5.002gamma
-#
-
 =head1 NAME
 
 Tk::JFileDialog - A highly configurable File Dialog widget for Perl/Tk.  
@@ -337,11 +329,11 @@ This code may be distributed under the same conditions as Perl itself.
 package Tk::JFileDialog;
 
 use vars qw($VERSION);
-$VERSION = '1.6';
+$VERSION = '1.61';
 
 require 5.002;
 use Tk;
-use Tk::JDialog;
+use Tk::Dialog;
 use Tk::JBrowseEntry;
 use Carp;
 use strict;
@@ -1683,7 +1675,7 @@ sub GetReturn
 				my($file) = $self->{Configure}{-File};
 				my($filename) = $fname;
 				eval "\$fname = \"$self->{Configure}{-EDlgText}\"";
-				$self->JDialog(-title => $self->{Configure}{-EDlgTitle},
+				$self->Dialog(-title => $self->{Configure}{-EDlgTitle},
 						-text => $fname,
 						-bitmap => 'error')
 						->Show;
@@ -1773,7 +1765,7 @@ sub GetReturn
 				my($file) = $self->{Configure}{-File};
 				my($filename) = $fname;
 				eval "\$fname = \"$self->{Configure}{-EDlgText}\"";
-				$self->JDialog(-title => $self->{Configure}{-EDlgTitle},
+				$self->Dialog(-title => $self->{Configure}{-EDlgTitle},
 						-text => $fname,
 						-bitmap => 'error')
 						->Show;
