@@ -1,8 +1,3 @@
-use lib '.';
-
-#BEGIN { $ENV{DBI_PUREPERL} = 2 };
-#require DBI;
-
 $^W = 1;
 
 # Before `make install' is performed this script should be runnable with
@@ -13,10 +8,8 @@ $^W = 1;
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..2\n"; }
+BEGIN { use lib './lib'; $| = 1; print "1..2\n"; use Tk::JFileDialog; $loaded = 1 }
 END {print "not ok 1\n" unless $loaded;}
-use Tk::JFileDialog;
-$loaded = 1;
 print "ok 1\n";
 
 ######################### End of black magic.
@@ -24,8 +17,8 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
-$ENV{PATH} .= ':.';
-system ("JFileDialogTest.pl") ? 
+#$ENV{PATH} .= ':.';
+system ("./JFileDialogTest.pl") ? 
 		print "not ok 2 ($@$?)\n" : print "ok 2\n";
 
 print "..done: 2 tests completed.\n";
